@@ -199,14 +199,7 @@ An advanced and lightning fast framework for gathering open-source intelligence
 
 
 Whats new in v{version_tag}?
-[{green}IMPROVED{reset}] Octosuite will now also run with command line arguments (use 'octosuite --help', to show usage)
-[{green}IMPROVED{reset}] Users will now be able to view previous commands with the ↑ ↓ arrow keys (for Windows systems)
-[{green}IMPROVED{reset}] Removed width from tables, so that they can auto adjust
-[{green}ADDED{reset}] Added the 'ls' command, which will be used to list all files and directories of the specified directory (beta)
-[{green}ADDED{reset}] Added the 'cd' command, which will be used to move to a specified directory (beta)
-[{green}ADDED{reset}] Added the 'log:clear' command, which will be used to clear all logs
-[{green}ADDED{reset}] Added the 'csv:clear' command, which will be used to clear all csv files
-[{green}GUI{reset}] The GUI will now come as a standalone executable
+[{green}FIXED{reset}]  Merged pull request from #9: bad indentation leading to reference before assignment error #9 
 
 Read the wiki: https://github.com/bellingcat/octosuite/wiki
 GitHub REST API documentation: https://docs.github.com/rest
@@ -527,7 +520,7 @@ class Octosuite:
         if response.status_code == 404:
             xprint(f"{NEGATIVE} {org_not_found.format(organization)}")
         elif response.status_code == 200:
-            org_profile_tree = Tree("\n" + response.json()['name'])
+            org_profile_tree = Tree("\n{response.json()['name']}")
             for attr in self.org_attrs:
                 org_profile_tree.add(f"{self.org_attr_dict[attr]}: {response.json()[attr]}")
             xprint(org_profile_tree)
@@ -547,7 +540,7 @@ class Octosuite:
         if response.status_code == 404:
             xprint(f"{NEGATIVE} {user_not_found.format(username)}")
         elif response.status_code == 200:
-            user_profile_tree = Tree("\n" + response.json()['name'])
+            user_profile_tree = Tree(f"\n{response.json()['name']}")
             for attr in self.profile_attrs:
                 user_profile_tree.add(f"{self.profile_attr_dict[attr]}: {response.json()[attr]}")
             xprint(user_profile_tree)
@@ -570,7 +563,7 @@ class Octosuite:
         if response.status_code == 404:
             xprint(f"{NEGATIVE} {repo_or_user_not_found.format(repo_name, username)}")
         elif response.status_code == 200:
-            repo_profile_tree = Tree("\n" + response.json()['full_name'])
+            repo_profile_tree = Tree(f"\n{response.json()['full_name']}")
             for attr in self.repo_attrs:
                 repo_profile_tree.add(f"{self.repo_attr_dict[attr]}: {response.json()[attr]}")
             xprint(repo_profile_tree)
@@ -776,8 +769,8 @@ class Octosuite:
                 events_tree = Tree("\n" + event['id'])
                 events_tree.add(f"Type: {event['type']}")
                 events_tree.add(f"Created at: {event['created_at']}")
-            xprint(events_tree)
-            xprint(event['payload'])
+                xprint(events_tree)
+                xprint(event['payload'])
             # log_org_events(event, organization)
         else:
             xprint(response.json())
